import numpy as np
from scipy.interpolate import make_interp_spline, BSpline, interp1d, PchipInterpolator


import matplotlib

matplotlib.use("Agg")
import matplotlib.pyplot as plt

# formatting

plt.rcParams.update(
    {
        "text.usetex": True,
        "font.family": "sans-serif",
        "font.sans-serif": "Helvetica",
        "font.size": 18,
        "text.latex.preamble": [r"\usepackage{sfmath} \boldmath"],
    }
)


num_samples = [1314, 2618, 5389, 10641, 16355, 22456]
remod_results = [15.7, 18.1, 18.3, 20.2, 22.0, 22.5]
base_results = [12.7, 15.2, 15.0, 15.9, 16.8, 17.2]


num_samples = [1314, 2618, 10641, 16355, 22456]
remod_results = [15.7, 18.1, 20.2, 22.0, 22.5]
base_results = [12.7, 15.5, 16.9, 17.8, 18.4]


num_samples_interp = np.linspace(min(num_samples), max(num_samples), 200)

remod_results_interp = PchipInterpolator(num_samples, remod_results)
base_results_interp = PchipInterpolator(num_samples, base_results)
# remod_results_interp = make_interp_spline(num_samples, remod_results, k=3)
# base_results_interp = make_interp_spline(num_samples, base_results, k=3)

remod_results_interp = remod_results_interp(num_samples_interp)
base_results_interp = base_results_interp(num_samples_interp)

plt.plot(num_samples, remod_results, label=r"$\mathcal{D}_{mod}$")
plt.plot(num_samples, base_results, label=r"$\mathcal{D}_{orig}$")

plt.xlabel("Number of training samples")
plt.ylabel(r"\textsc{Pass@}1")
plt.legend(loc="lower right")
# plt.xscale("log")

# latex bold xtick and ytick values
plt.xticks(fontsize=18, fontweight="bold")
plt.yticks(fontsize=18, fontweight="bold")
plt.grid(True, which="both", axis="both", ls="-", color="0.65")


plt.savefig("figures/results/plot.pdf", bbox_inches="tight")
plt.close()

plt.plot(num_samples_interp, remod_results_interp, label=r"$\mathcal{D}_{mod}$")
plt.plot(num_samples_interp, base_results_interp, label=r"$\mathcal{D}_{orig}$")

plt.xlabel("Number of training samples")
plt.ylabel(r"\textsc{Pass@}1")
plt.legend(loc="lower right")
# plt.xscale("log")

# latex bold xtick and ytick values
plt.xticks(fontsize=18, fontweight="bold")
plt.yticks(fontsize=18, fontweight="bold")
plt.grid(True, which="both", axis="both", ls="-", color="0.65")


plt.savefig("figures/results/plot_interp.pdf", bbox_inches="tight", dpi=200)
